@@ -68,19 +68,19 @@ class EulithWETH(WETHInterface, EulithERC20):
         super().__init__(eulith_web3, contract_address)
         self.decimals = 18
 
-    def deposit_eth(self, whole_eth_as_float: float):
+    def deposit_eth(self, whole_eth_as_float: float, override_tx_parameters: Optional[TxParams] = None):
         wei = int(whole_eth_as_float * 1e18)  # convert to wei
-        return self.deposit_wei(wei)
+        return self.deposit_wei(wei, override_tx_parameters)
 
-    def deposit_wei(self, wei: int) -> TxParams:
-        tx = self.deposit()
+    def deposit_wei(self, wei: int, override_tx_parameters: Optional[TxParams] = None) -> TxParams:
+        tx = self.deposit(override_tx_parameters)
         tx['value'] = hex(wei)
         tx['gas'] = 60000  # estimates are a little flaky here
         return tx
 
     # You must have sufficient WETH balance for this to succeed
-    def withdraw_eth(self, whole_eth_as_float: float) -> TxParams:
+    def withdraw_eth(self, whole_eth_as_float: float, override_tx_parameters: Optional[TxParams] = None) -> TxParams:
         wei = int(whole_eth_as_float * 1e18)
-        tx = self.withdraw(wei)
+        tx = self.withdraw(wei, override_tx_parameters)
         tx['gas'] = 60000  # estimates are a little flaky here
         return tx
